getAvailableBiometrics method

Future<List<BiometricType>> getAvailableBiometrics()
inherited

Returns a list of the biometrics that the app can currently use for authentication.

Note that this may not include all biometrics enrolled on the device. For example, on iOS, biometrics may be enrolled on the device but remain unavailable to the app if the user has not granted the required permissions to use them.

Implementation

Future<List<BiometricType>> getAvailableBiometrics() =>
    LocalAuthPlatform.instance.getEnrolledBiometrics();