ReceivablesAccount class abstract

Available extensions
Annotations
  • @Freezed.new(makeCollectionsUnmodifiable: false)

Constructors

ReceivablesAccount({@JsonKey.new(name: 'id') String? id, @JsonKey.new(name: 'name') String? name, @JsonKey.new(name: 'is_active') bool? isActive, @JsonKey.new(name: 'number') String? number, @JsonKey.new(name: 'tag') String? tag, @JsonKey.new(name: 'description') String? description})
factory
ReceivablesAccount.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $ReceivablesAccountCopyWith<ReceivablesAccount>
Create a copy of ReceivablesAccount with the given fields replaced by the non-null parameter values.
no setterinherited
description String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String?
no setterinherited
isActive bool?
no setterinherited
name String?
no setterinherited
number String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ReceivablesAccount value)) → TResult

Available on ReceivablesAccount, provided by the ReceivablesAccountPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ReceivablesAccount value)?) → TResult?

Available on ReceivablesAccount, provided by the ReceivablesAccountPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ReceivablesAccount value)?, {required TResult orElse()}) → TResult

Available on ReceivablesAccount, provided by the ReceivablesAccountPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? id, String? name, bool? isActive, String? number, String? tag, String? description)?, {required TResult orElse()}) → TResult

Available on ReceivablesAccount, provided by the ReceivablesAccountPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ReceivablesAccount to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? id, String? name, bool? isActive, String? number, String? tag, String? description)) → TResult

Available on ReceivablesAccount, provided by the ReceivablesAccountPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? id, String? name, bool? isActive, String? number, String? tag, String? description)?) → TResult?

Available on ReceivablesAccount, provided by the ReceivablesAccountPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited